@@ -604,7 +604,8 @@ void RPackageViewOrigin::addPackage(RPackage *package)
         Ver.end() == false; Ver++)
    {
       pkgCache::VerFileIterator VF = Ver.FileList();
-      if ( (VF.end() == true) || (VF.File() == NULL) )
+      if ( (VF.end() == true) || (VF.File() == NULL) || 
+           (VF.File().Archive() == NULL) || (VF.File().Site() == NULL) )
          continue;
       // ignore versions that are lower or equal than the candidate
       if (_system->VS->CmpVersion(Ver.VerStr(), 
